@@ -16,7 +16,9 @@ Why does this file exist, and why not put this in __main__?
 """
 import argparse
 import sys
+import os
 from typing import Optional, Sequence
+from random import choice as random
 
 from requests.exceptions import ConnectionError
 
@@ -27,11 +29,13 @@ from .constants import (
     EXPIRY_TIME_HINT,
     LANGUAGES,
     LANGUAGES_HINT,
+    LANGUAGES_EXTENSIONS,
     PASTEME_SERVICE_URL,
     THEMES,
     THEMES_HINT,
 )
 from .sdk import PasteMe
+from .shapes import CHARACTERS
 
 parser = argparse.ArgumentParser(
     description=f'A CLI pastebin tool interacting with PasteMe ({PASTEME_SERVICE_URL}) RESTful APIs.',
@@ -49,7 +53,6 @@ parser.add_argument(
     '-l',
     '--language',
     metavar='',
-    default='plaintext',
     type=str,
     choices=LANGUAGES.keys(),
     help=LANGUAGES_HINT,
@@ -99,10 +102,13 @@ parser.add_argument(
     help='script file',
 )
 
+def detect_language(file):
+    file_extension = os.path.splitext(file)[1]
+    return LANGUAGES_EXTENSIONS.get(file_extension,'plaintext')
 
 def main(args: Optional[Sequence[str]] = None) -> None:
     args = parser.parse_args(args=args)
-
+    language = detect_language(args.file.name) if not args.language else args.language
     with args.file as source_code:
         code_lines = source_code.readlines()
 
@@ -124,11 +130,11 @@ def main(args: Optional[Sequence[str]] = None) -> None:
         resp = snippet.create(
             title=args.title,
             body=''.join(code_lines),
-            language=args.language,
+            language=language,
             theme=args.theme,
             expires_in=expiry_days[args.expiry_time],
         )
-        print(f'PASTE --> {resp.url}')
+        print(random(CHARACTERS).format(resp.url))
         sys.exit()
     except ConnectionError:
         sys.exit(CONNECTION_ISSUE_HINT)
